#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cborg-json
version:              0.2.6.0
visibility:           public
id:                   cborg-json-0.2.6.0-C3o2jB98lnfBQ8etX6Kndc
key:                  cborg-json-0.2.6.0-C3o2jB98lnfBQ8etX6Kndc
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A library for encoding JSON as CBOR
description:
    This package implements the bijection between JSON and
    CBOR defined in the CBOR specification, RFC 7049.

category:             Codec
abi:                  207bdc407f0097ba22ddf54f45bd0a10
exposed:              True
exposed-modules:      Codec.CBOR.JSON
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cborg-json-0.2.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cborg-json
hs-libraries:         HScborg-json-0.2.6.0-C3o2jB98lnfBQ8etX6Kndc
depends:
    aeson-2.2.1.0-B4RqQZAnAt5HkJbmyrGfNz
    aeson-pretty-0.8.10-FzerwUFuCwVFAzZJsDIw6C base-4.18.2.1
    base64-bytestring-1.2.1.0-KFieoz0Zw8V2RvHGFxevKT
    cborg-0.2.10.0-DD1TQXesB9AAufXsb9Ge1f
    scientific-0.3.8.0-HLdXvCiO3QbIUecoSvRoN5 text-2.0.2
    unordered-containers-0.2.20.1-C4c13QuwLgs7TJHWi6VHCN
    vector-0.13.2.0-AKpLem9JWa2IilUORfhwQi

haddock-interfaces:   /usr/share/doc/haskell-cborg-json/html/cborg-json.haddock
haddock-html:         /usr/share/doc/haskell-cborg-json/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

